(Uncle Profile) เป็นตัวอย่างการอัพโหลด package ไปยัง pypi.org
=============================================================

PyPi: https://pypi.org/project/pysci/

สวัสดีจ้าาาา

วิธีติดตั้ง
~~~~~~~~~~~

เปิด CMD / Terminal

.. code:: python

   pip install pysci

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

.. code:: python

   from pysci import Py

   my = Py('')
   my.a()
   my.b()

พัฒนาโดย: \***\* FB: \****\*

YouTube: \***\*
